@@ -3,6 +3,7 @@
 //! These must be updated when dittoffi changes
 #![deny(unsafe_op_in_unsafe_fn)]
 #![recursion_limit = "256"]
+#![allow(clippy::needless_arbitrary_self_type)]
 
 use ::macro_rules_attribute::apply;
 use ::std::{
@@ -658,6 +659,16 @@ extern "C" {
     pub fn ditto_timeseries_event_free(document: c::Box<TimeseriesEvent>);
 
     pub fn ditto_set_sync_group(ditto: &'_ Ditto, sync_group: c_uint);
+
+    pub fn ditto_register_presence_v2_callback(
+        ditto: &'_ Ditto,
+        ctx: *mut c_void,
+        retain: Option<unsafe extern "C" fn(*mut c_void)>,
+        release: Option<unsafe extern "C" fn(*mut c_void)>,
+        c_cb: Option<unsafe extern "C" fn(*mut c_void, json: char_p::Ref<'_>)>,
+    );
+
+    pub fn ditto_presence_v2(ditto: &'_ Ditto) -> char_p::Box;
 }
 
 #[cfg(test)]
